@@ -302,6 +302,7 @@ class Tests(object):
         @wraps(func)
         def wrapper():
             with nested(*[ctx() for ctx in self._contexts]) as context:
+                context = [c for c in context if c is not None]
                 if len(inspect.getargspec(func)[0]) != 0:
                     args = []
                     for arg in context:
@@ -643,7 +644,12 @@ class Assert(object):
 
             Assert(True).is_(True)
 
+        .. versionchanged:: 0.3
+            Checks the wrapped object for :class:`Assert` instances.
+
         """
+        if isinstance(obj, Assert):
+            obj = obj.obj
         return assert_(self.obj is obj, '%r is not %r' % (self.obj, obj))
 
     def is_not(self, obj):
@@ -652,7 +658,12 @@ class Assert(object):
 
             Assert([]).is_not([])
 
+        .. versionchanged:: 0.3
+            Checks the wrapped object for :class:`Assert` instances.
+
         """
+        if isinstance(obj, Assert):
+            obj = obj.obj
         return assert_(self.obj is not obj, '%r is %r' % (self.obj, obj))
 
     def __contains__(self, obj):
